@@ -289,7 +289,7 @@ class DropboxClient(object):
         return RESTClient.POST(url, params, headers)
 
 
-    def metadata(self, path, list=True, file_limit=10000, hash=None, rev=None):
+    def metadata(self, path, list=True, file_limit=10000, hash=None, rev=None, include_deleted=False):
         """Retrieve metadata for a file or folder.
 
         Args:
@@ -328,6 +328,7 @@ class DropboxClient(object):
 
         params = {'file_limit': file_limit,
                   'list': 'true',
+                  'include_deleted': include_deleted,
                   }
 
         if not list:
@@ -438,7 +439,7 @@ class DropboxClient(object):
 
         url, params, headers = self.request(path, params)
 
-        return RESTClient.POST(url, params, headers)
+        return RESTClient.GET(url, headers)
 
     def restore(self, path, rev):
         """Restore a file to a previous revision.
