@@ -11,6 +11,8 @@ import urllib
 import urlparse
 import os
 
+SDK_VERSION = "1.2"
+
 class RESTClient(object):
     """
     An class with all static methods to perform JSON REST requests that is used internally
@@ -48,6 +50,7 @@ class RESTClient(object):
         """
         post_params = post_params or {}
         headers = headers or {}
+        headers['User-Agent'] = 'OfficialDropboxPythonSDK/' + SDK_VERSION
 
         if post_params:
             if body:
@@ -161,6 +164,7 @@ class ErrorResponse(Exception):
 
     def __init__(self, http_resp):
         self.status = http_resp.status
+        self.reason = http_resp.reason
         self.body = http_resp.read()
 
         try:
@@ -177,6 +181,8 @@ class ErrorResponse(Exception):
             msg = "%s (%s)" % (self.user_error_msg, self.error_msg)
         elif self.error_msg:
             msg = self.error_msg
+        elif not self.body:
+            msg = self.reason
         else:
             msg = "Error parsing response body: %s" % self.body
 
